#
# spec file for package xdg-desktop-portal-pantheon
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         appid io.elementary.portals
Name:           xdg-desktop-portal-pantheon
Version:        8.0.1
Release:        1.1
Summary:        Pantheon Backend Portal
License:        GPL-3.0-or-later
URL:            https://github.com/elementary/portals
Source0:        %{url}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  meson >= 0.58.0
BuildRequires:  pkgconfig
BuildRequires:  vala >= 0.56.1
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(granite-7)
BuildRequires:  pkgconfig(gsettings-desktop-schemas)
BuildRequires:  pkgconfig(gtk4-wayland)
BuildRequires:  pkgconfig(gtk4-x11)
BuildRequires:  pkgconfig(pantheon-wayland-1)
BuildRequires:  pkgconfig(systemd)
BuildRequires:  pkgconfig(vte-2.91-gtk4)
BuildRequires:  pkgconfig(x11)

%description
A Pantheon backend implementation for xdg-desktop-portal.

This package provides D-Bus interfaces that are used by xdg-desktop-portal
to implement portals.

%lang_package

%prep
%autosetup -n portals-%{version}

%build
export CFLAGS="%{optflags} -Wno-error=return-type"
%meson
%meson_build

%install
%meson_install
%find_lang %{name}
%fdupes %{buildroot}%{_datadir}

%files
%license COPYING
%doc README.md
%{_userunitdir}/%{name}.service
%{_libexecdir}/%{name}
%{_datadir}/dbus-1/services/org.freedesktop.impl.portal.desktop.pantheon.service
%{_datadir}/metainfo/%{appid}.metainfo.xml
%{_datadir}/xdg-desktop-portal/portals/pantheon.portal
%dir %{_datadir}/{xdg-desktop-portal,xdg-desktop-portal/portals}

%files lang -f %{name}.lang

%changelog
* Thu May  8 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 8.0.1:
  * Portal: Make autostart directory if not exists
  * Check for redacted font
  * Updated translations
* Tue Nov 19 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 8.0.0:
  * Access/Dialog: Center and keep above on wayland
  * updated translations
* Tue Nov  5 2024 Richard Rahl <rrahl0@opensuse.org>
- fix CFLAGS (accidently removed all optflags)
* Sat Aug 10 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 7.2.0:
  * Updated translations
- update to 7.1.1:
  * Updated translations
- update to 7.1.0:
  * Add build support for older Vala versions
  * Background portal implementation
  * NotificationRequest: use typographical quotes
  * Background: use commandline to try to get fallback app_id
  * Background: Make Asynchronous
  * Background: Make send_notification async and let it throw errors
- update to 7.0.0:
  * AppChooser: Make primary text translatable
  * Update Meson Files
  * Updated to gtk4
  * Metainfo improvements
- update to 1.2.0:
  * Support dialog parenting on wayland
  * Updated translations
- update sourceurl to newer upstream url, switch url to github
* Sun Feb 20 2022 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.1.0:
  * Add a destructive action option for access portals
  * Fix a crash when opening apps in the AppChooser portal
  * Fix window focus and position for Access portals with no
    parent window
  * Set AppChooser portal as a modal dialog for proper animations
* Fri Nov  5 2021 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.0.1:
  * Update appdata.xml for #34 (#35)
  * Watch for xdg-desktop-portal starting before binding style
    scheme (#34)
  * Release 1.0.0 (#32)
  * build: add systemduserunitdir option (#3)
  * Create COPYING
  * Create README.md
* Fri Aug 16 2019 Alexei Podvalsky <avvissu@yandex.by>
- Initial package
